pitchtools.PitchArray
=====================

.. abjad-lineage:: abjad.tools.pitchtools.PitchArray.PitchArray

.. autoclass:: abjad.tools.pitchtools.PitchArray.PitchArray

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.PitchArray.PitchArray.append_column
      ~abjad.tools.pitchtools.PitchArray.PitchArray.append_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.apply_pitches_by_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.cell_tokens_by_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.cell_widths_by_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.cells
      ~abjad.tools.pitchtools.PitchArray.PitchArray.columns
      ~abjad.tools.pitchtools.PitchArray.PitchArray.copy_subarray
      ~abjad.tools.pitchtools.PitchArray.PitchArray.depth
      ~abjad.tools.pitchtools.PitchArray.PitchArray.dimensions
      ~abjad.tools.pitchtools.PitchArray.PitchArray.from_score
      ~abjad.tools.pitchtools.PitchArray.PitchArray.has_spanning_cell_over_index
      ~abjad.tools.pitchtools.PitchArray.PitchArray.has_voice_crossing
      ~abjad.tools.pitchtools.PitchArray.PitchArray.is_rectangular
      ~abjad.tools.pitchtools.PitchArray.PitchArray.list_nonspanning_subarrays
      ~abjad.tools.pitchtools.PitchArray.PitchArray.pad_to_depth
      ~abjad.tools.pitchtools.PitchArray.PitchArray.pad_to_width
      ~abjad.tools.pitchtools.PitchArray.PitchArray.pitches
      ~abjad.tools.pitchtools.PitchArray.PitchArray.pitches_by_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.pop_column
      ~abjad.tools.pitchtools.PitchArray.PitchArray.pop_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.remove_row
      ~abjad.tools.pitchtools.PitchArray.PitchArray.rows
      ~abjad.tools.pitchtools.PitchArray.PitchArray.size
      ~abjad.tools.pitchtools.PitchArray.PitchArray.to_measures
      ~abjad.tools.pitchtools.PitchArray.PitchArray.voice_crossing_count
      ~abjad.tools.pitchtools.PitchArray.PitchArray.weight
      ~abjad.tools.pitchtools.PitchArray.PitchArray.width
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__add__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__contains__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__copy__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__eq__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__format__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__getitem__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__hash__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__iadd__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__ne__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__repr__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__setitem__
      ~abjad.tools.pitchtools.PitchArray.PitchArray.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.cell_tokens_by_row
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.cell_widths_by_row
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.cells
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.columns
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.depth
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.dimensions
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.has_voice_crossing
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.is_rectangular
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.pitches
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.pitches_by_row
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.rows
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.size
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.voice_crossing_count
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.weight
   :noindex:

.. autoattribute:: abjad.tools.pitchtools.PitchArray.PitchArray.width
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.append_column
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.append_row
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.apply_pitches_by_row
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.copy_subarray
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.has_spanning_cell_over_index
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.list_nonspanning_subarrays
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.pad_to_depth
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.pad_to_width
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.pop_column
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.pop_row
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.remove_row
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.to_measures
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.from_score
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__copy__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__hash__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__iadd__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__setitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.PitchArray.PitchArray.__str__
   :noindex:
